/*
 * Partition table definitions for flashnand and friends
 *
 * (C) Copyright 2006-2007, Axis Communications AB, LUND, SWEDEN
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#define PARTITION_TABLE_OFFSET 10 /* skip jump header length */
#define PARTITION_TABLE_MAGIC 0xbeef /* Not a good magic */

/* The partitiontable_head is located at offset +10: */
struct partitiontable_head {
	unsigned short magic; /* PARTITION_TABLE_MAGIC */ 
	unsigned short size;  /* Length of ptable block (entries + end marker) */
	unsigned long checksum; /* dword sum, over entries + end marker  */
}__attribute__((packed));

/* And followed by partition table entries */
struct partitiontable_entry {
	unsigned long offset;   /* relative to the sector the ptable is in */
	unsigned long size;	/* in bytes */
	unsigned long checksum; /* simple longword sum */
	unsigned short type;	/* see type codes below */
	unsigned short flags;	/* bit 0: ro/rw = 1/0 */
	unsigned long future0;	/* 16 bytes reserved for future use */
	unsigned long future1;
	unsigned long future2;
	unsigned long future3;
}__attribute__((packed));
/* ended by an end marker: */
#define PARTITIONTABLE_END_MARKER 0xFFFFFFFF
#define PARTITIONTABLE_END_MARKER_SIZE 4

#define PARTITIONTABLE_END_PAD	10

/* Complete structure for whole partition table */
/* note that table may end before CONFIG_ETRAX_PTABLE_ENTRIES by setting
 * offset of the last entry + 1 to PARTITIONTABLE_END_MARKER.
 */
struct partitiontable {
	unsigned char skip[PARTITION_TABLE_OFFSET];
	struct partitiontable_head head;
	struct partitiontable_entry entries[];
}__attribute__((packed));

#define PARTITION_TYPE_RESCUE 0xD00D /* internal use only, never in image */
#define PARTITION_TYPE_PARAM  0x0001
#define PARTITION_TYPE_KERNEL 0x0002
#define PARTITION_TYPE_JFFS   0x0003
#define PARTITION_TYPE_JFFS2  0x0000 /* pity */

#define	PARTITION_FLAGS_READONLY_MASK	0x0001
#define	PARTITION_FLAGS_READONLY	0x0001


